# command
```shell
pipx install pwsh-utils
say -t 'hello world' # cowsay
os # operating system
dt # datetime
sec # seconds
ms # milliseconds
nano # nanoseconds
env 'PATH' # echo environment variable
```